@@ -37,6 +37,8 @@ class Resampling(IntEnum):
     'nearest', 'bilinear', 'cubic', 'cubic_spline', 'lanczos',
     'average', 'mode' are always available (GDAL >= 1.10).
 
+    'sum' is only supported in GDAL >= 3.1.
+
     'rms' is only supported in GDAL >= 3.3.
 
     Note: 'gauss' is not available to the functions in rio.warp.
@@ -54,6 +56,31 @@ class Resampling(IntEnum):
     med = 10
     q1 = 11
     q3 = 12
+    sum = 13
+    rms = 14
+
+
+class _OverviewResampling(IntEnum):
+    """Available Overview resampling algorithms.
+
+    The first 8, 'nearest', 'bilinear', 'cubic', 'cubic_spline',
+    'lanczos', 'average', 'mode', and 'gauss', are available for making
+    dataset overviews.
+
+    'nearest', 'bilinear', 'cubic', 'cubic_spline', 'lanczos',
+    'average', 'mode' are always available (GDAL >= 1.10).
+
+    'rms' is only supported in GDAL >= 3.3.
+
+    """
+    nearest = 0
+    bilinear = 1
+    cubic = 2
+    cubic_spline = 3
+    lanczos = 4
+    average = 5
+    mode = 6
+    gauss = 7
     rms = 14
 
 
@@ -97,6 +124,7 @@ class PhotometricInterp(Enum):
     icclab = 'ICCLAB'
     itulab = 'ITULAB'
 
+
 class MergeAlg(Enum):
     """Available rasterization algorithms"""
     replace = 'REPLACE'
