@@ -2,24 +2,23 @@
 
 
 import logging
-import warnings
 import math
 import os
+import warnings
 
 import numpy as np
 
 import rasterio
-from rasterio._features import _shapes, _sieve, _rasterize, _bounds
-from rasterio.crs import CRS
-from rasterio.dtypes import validate_dtype, can_cast_dtype, get_minimum_dtype
+from rasterio.dtypes import validate_dtype, can_cast_dtype, get_minimum_dtype, _getnpdtype
 from rasterio.enums import MergeAlg
 from rasterio.env import ensure_env
 from rasterio.errors import ShapeSkipWarning
+from rasterio._features import _shapes, _sieve, _rasterize, _bounds
+from rasterio import warp
 from rasterio.rio.helpers import coords
 from rasterio.transform import Affine
-from rasterio.transform import IDENTITY, guard_transform
+from rasterio.transform import IDENTITY, guard_transform, rowcol
 from rasterio.windows import Window
-from rasterio import warp
 
 log = logging.getLogger(__name__)
 
@@ -277,7 +276,7 @@ def rasterize(
         if dtype is not None and not can_cast_dtype(default_value_array, dtype):
             raise ValueError(format_cast_error('default_vaue', dtype))
 
-    if dtype is not None and np.dtype(dtype).name not in valid_dtypes:
+    if dtype is not None and _getnpdtype(dtype).name not in valid_dtypes:
         raise ValueError(format_invalid_dtype('dtype'))
 
     valid_shapes = []
@@ -333,7 +332,7 @@ def rasterize(
         raise ValueError(format_cast_error('shape values', dtype))
 
     if out is not None:
-        if np.dtype(out.dtype).name not in valid_dtypes:
+        if _getnpdtype(out.dtype).name not in valid_dtypes:
             raise ValueError(format_invalid_dtype('out'))
 
         if not can_cast_dtype(shape_values, out.dtype):
@@ -391,89 +390,81 @@ def bounds(geometry, north_up=True, transform=None):
     return _bounds(geom, north_up=north_up, transform=transform)
 
 
-def geometry_window(dataset, shapes, pad_x=0, pad_y=0, north_up=True,
-                    rotated=False, pixel_precision=3):
-    """Calculate the window within the raster that fits the bounds of the
-    geometry plus optional padding.  The window is the outermost pixel indices
-    that contain the geometry (floor of offsets, ceiling of width and height).
+def geometry_window(
+    dataset,
+    shapes,
+    pad_x=0,
+    pad_y=0,
+    north_up=None,
+    rotated=None,
+    pixel_precision=None,
+    boundless=False,
+):
+    """Calculate the window within the raster that fits the bounds of
+    the geometry plus optional padding.  The window is the outermost
+    pixel indices that contain the geometry (floor of offsets, ceiling
+    of width and height).
 
     If shapes do not overlap raster, a WindowError is raised.
 
     Parameters
     ----------
-    dataset: dataset object opened in 'r' mode
+    dataset : dataset object opened in 'r' mode
         Raster for which the mask will be created.
-    shapes: iterable over geometries.
-        A geometry is a GeoJSON-like object or implements the geo interface.
-        Must be in same coordinate system as dataset.
-    pad_x: float
-        Amount of padding (as fraction of raster's x pixel size) to add to left
-        and right side of bounds.
-    pad_y: float
-        Amount of padding (as fraction of raster's y pixel size) to add to top
-        and bottom of bounds.
-    north_up: bool
-        If True (default), the origin point of the raster's transform is the
-        northernmost point and y pixel values are negative.
-    rotated: bool
-        If true, some rotation terms exist in the dataset transform (this
-        requires special attention.)
-    pixel_precision: int
-        Number of places of rounding precision for evaluating bounds of shapes.
+    shapes : iterable over geometries.
+        A geometry is a GeoJSON-like object or implements the geo
+        interface.  Must be in same coordinate system as dataset.
+    pad_x : float
+        Amount of padding (as fraction of raster's x pixel size) to add
+        to left and right side of bounds.
+    pad_y : float
+        Amount of padding (as fraction of raster's y pixel size) to add
+        to top and bottom of bounds.
+    north_up : optional
+        This parameter is ignored since version 1.2.1. A deprecation
+        warning will be emitted in 1.3.0.
+    rotated : optional
+        This parameter is ignored since version 1.2.1. A deprecation
+        warning will be emitted in 1.3.0.
+    pixel_precision : int or float, optional
+        Number of places of rounding precision or absolute precision for
+        evaluating bounds of shapes.
+    boundless : bool, optional
+        Whether to allow a boundless window or not.
 
     Returns
     -------
-    window: rasterio.windows.Window instance
+    rasterio.windows.Window
+
     """
 
-    if pad_x:
-        pad_x = abs(pad_x * dataset.res[0])
+    all_bounds = [bounds(shape, transform=~dataset.transform) for shape in shapes]
 
-    if pad_y:
-        pad_y = abs(pad_y * dataset.res[1])
+    cols = [
+        x
+        for (left, bottom, right, top) in all_bounds
+        for x in (left - pad_x, right + pad_x, right + pad_x, left - pad_x)
+    ]
+    rows = [
+        y
+        for (left, bottom, right, top) in all_bounds
+        for y in (top - pad_y, top - pad_y, bottom + pad_y, bottom + pad_y)
+    ]
 
-    if not rotated:
-        all_bounds = [bounds(shape, north_up=north_up) for shape in shapes]
-        lefts, bottoms, rights, tops = zip(*all_bounds)
+    row_start, row_stop = int(math.floor(min(rows))), int(math.ceil(max(rows)))
+    col_start, col_stop = int(math.floor(min(cols))), int(math.ceil(max(cols)))
 
-        left = min(lefts) - pad_x
-        right = max(rights) + pad_x
-
-        if north_up:
-            bottom = min(bottoms) - pad_y
-            top = max(tops) + pad_y
-        else:
-            bottom = max(bottoms) + pad_y
-            top = min(tops) - pad_y
-    else:
-        # get the bounds in the pixel domain by specifying a transform to the bounds function
-        all_bounds_px = [bounds(shape, transform=~dataset.transform) for shape in shapes]
-        # get left, right, top, and bottom as above
-        lefts, bottoms, rights, tops = zip(*all_bounds_px)
-        left = min(lefts) - pad_x
-        right = max(rights) + pad_x
-        top = min(tops) - pad_y
-        bottom = max(bottoms) + pad_y
-        # do some clamping if there are any values less than zero or greater than dataset shape
-        left = max(0, left)
-        top = max(0, top)
-        right = min(dataset.shape[1], right)
-        bottom = min(dataset.shape[0], bottom)
-        # convert the bounds back to the CRS domain
-        left, top = dataset.transform * (left, top)
-        right, bottom = dataset.transform * (right, bottom)
-
-    window = dataset.window(left, bottom, right, top)
-    window_floored = window.round_offsets(op='floor', pixel_precision=pixel_precision)
-    w = math.ceil(window.width + window.col_off - window_floored.col_off)
-    h = math.ceil(window.height + window.row_off - window_floored.row_off)
-    window = Window(window_floored.col_off, window_floored.row_off, w, h)
+    window = Window(
+        col_off=col_start,
+        row_off=row_start,
+        width=max(col_stop - col_start, 0.0),
+        height=max(row_stop - row_start, 0.0),
+    )
 
     # Make sure that window overlaps raster
     raster_window = Window(0, 0, dataset.width, dataset.height)
-
-    # This will raise a WindowError if windows do not overlap
-    window = window.intersection(raster_window)
+    if not boundless:
+        window = window.intersection(raster_window)
 
     return window
 
