@@ -85,7 +85,7 @@ class MemoryFile(MemoryFileBase):
      'width': 791}
 
     """
-    def __init__(self, file_or_bytes=None, filename=None, ext=''):
+    def __init__(self, file_or_bytes=None, dirname=None, filename=None, ext='.tif'):
         """Create a new file in memory
 
         Parameters
@@ -101,8 +101,9 @@ class MemoryFile(MemoryFileBase):
         -------
         MemoryFile
         """
-        super(MemoryFile, self).__init__(
-            file_or_bytes=file_or_bytes, filename=filename, ext=ext)
+        super().__init__(
+            file_or_bytes=file_or_bytes, dirname=dirname, filename=filename, ext=ext
+        )
 
     @ensure_env
     def open(self, driver=None, width=None, height=None, count=None, crs=None,
@@ -125,7 +126,7 @@ class MemoryFile(MemoryFileBase):
 
         if self.closed:
             raise IOError("I/O operation on closed file.")
-        if self.exists():
+        if len(self) > 0:
             log.debug("VSI path: {}".format(mempath.path))
             return DatasetReader(mempath, driver=driver, sharing=sharing, **kwargs)
         else:
@@ -141,8 +142,8 @@ class MemoryFile(MemoryFileBase):
         return self
 
     def __exit__(self, *args, **kwargs):
-        self._env.__exit__()
         self.close()
+        self._env.__exit__()
 
 
 class ZipMemoryFile(MemoryFile):
@@ -153,7 +154,7 @@ class ZipMemoryFile(MemoryFile):
     """
 
     def __init__(self, file_or_bytes=None):
-        super(ZipMemoryFile, self).__init__(file_or_bytes, ext='zip')
+        super().__init__(file_or_bytes, ext="zip")
 
     @ensure_env
     def open(self, path, driver=None, sharing=False, **kwargs):
