@@ -9,6 +9,7 @@ from . import options
 import rasterio
 from rasterio.coords import disjoint_bounds
 from rasterio.crs import CRS
+from rasterio.enums import MaskFlags
 from rasterio.windows import Window
 
 logger = logging.getLogger(__name__)
@@ -43,6 +44,7 @@ projection_projected_opt = click.option(
     type=click.Path(exists=True),
     help='Raster dataset to use as a template for bounds')
 @options.format_opt
+@options.nodata_opt
 @projection_geographic_opt
 @projection_projected_opt
 @options.overwrite_opt
@@ -60,6 +62,7 @@ def clip(
     bounds,
     like,
     driver,
+    nodata,
     projection,
     overwrite,
     creation_options,
@@ -67,10 +70,6 @@ def clip(
 ):
     """Clips a raster using projected or geographic bounds.
 
-    \b
-      $ rio clip input.tif output.tif --bounds xmin ymin xmax ymax
-      $ rio clip input.tif output.tif --like template.tif
-
     The values of --bounds are presumed to be from the coordinate
     reference system of the input dataset unless the --geographic option
     is used, in which case the values may be longitude and latitude
@@ -78,13 +77,18 @@ def clip(
     plain text "west south east north" representations of a bounding box
     are acceptable.
 
-    If using --like, bounds will automatically be transformed to match the
-    coordinate reference system of the input.
+    If using --like, bounds will automatically be transformed to match
+    the coordinate reference system of the input.
 
-    It can also be combined to read bounds of a feature dataset using Fiona:
+    Datasets with non-rectilinear geo transforms (i.e. with rotation
+    and/or shear) may not be cropped using this command. They must be
+    processed with rio-warp.
 
-    \b
-      $ rio clip input.tif output.tif --bounds $(fio info features.shp --bounds)
+    Examples
+    --------
+    $ rio clip input.tif output.tif --bounds xmin ymin xmax ymax
+
+    $ rio clip input.tif output.tif --like template.tif
 
     """
     from rasterio.warp import transform_bounds
@@ -95,6 +99,11 @@ def clip(
         input = files[0]
 
         with rasterio.open(input) as src:
+            if not src.transform.is_rectilinear:
+                raise click.BadParameter(
+                    "Non-rectilinear rasters (i.e. with rotation or shear) cannot be clipped"
+                )
+
             if bounds:
                 if projection == 'geographic':
                     bounds = transform_bounds(CRS.from_epsg(4326), src.crs, *bounds)
@@ -134,13 +143,18 @@ def clip(
             width = int(out_window.width)
 
             out_kwargs = src.profile
-            out_kwargs.pop("driver", None)
+
             if driver:
                 out_kwargs["driver"] = driver
+
+            if nodata is not None:
+                out_kwargs["nodata"] = nodata
+
             out_kwargs.update({
                 'height': height,
                 'width': width,
                 'transform': src.window_transform(out_window)})
+
             out_kwargs.update(**creation_options)
 
             if "blockxsize" in out_kwargs and int(out_kwargs["blockxsize"]) > width:
@@ -160,5 +174,18 @@ def clip(
                         window=out_window,
                         out_shape=(src.count, height, width),
                         boundless=True,
+                        masked=True,
                     )
                 )
+
+                if MaskFlags.per_dataset in src.mask_flag_enums[0]:
+                    out.write_mask(
+                        src.read_masks(
+                            window=out_window,
+                            out_shape=(src.count, height, width),
+                            boundless=True,
+                        )[0]
+                    )
+
+                # TODO: copy other properties (GCPs etc). Several other
+                # programs need the same utility.
