@@ -100,7 +100,9 @@ class Session(object):
         if isinstance(path, UnparsedPath) or path.is_local:
             return DummySession
 
-        elif path.scheme == "s3" or "amazonaws.com" in path.path:
+        elif (
+            path.scheme == "s3" or "amazonaws.com" in path.path
+        ) and not "X-Amz-Signature" in path.path:
             if boto3 is not None:
                 return AWSSession
             else:
@@ -283,7 +285,7 @@ class AWSSession(Session):
         self.unsigned = bool(os.getenv("AWS_NO_SIGN_REQUEST", aws_unsigned))
         self.endpoint_url = endpoint_url
         self._creds = (
-            self._session._session.get_credentials()
+            self._session.get_credentials()
             if not self.unsigned and self._session
             else None
         )
@@ -544,7 +546,8 @@ class AzureSession(Session):
     """Configures access to secured resources stored in Microsoft Azure Blob Storage.
     """
     def __init__(self, azure_storage_connection_string=None,
-                 azure_storage_account=None, azure_storage_access_key=None):
+                 azure_storage_account=None, azure_storage_access_key=None,
+                 azure_unsigned=False):
         """Create new Microsoft Azure Blob Storage session
 
         Parameters
@@ -555,16 +558,25 @@ class AzureSession(Session):
             An account name
         azure_storage_access_key: string
             A secret key
+        azure_unsigned : bool, optional (default: False)
+            If True, requests will be unsigned.
         """
 
+        self.unsigned = bool(os.getenv("AZURE_NO_SIGN_REQUEST", azure_unsigned))
+        self.storage_account = os.getenv("AZURE_STORAGE_ACCOUNT", azure_storage_account)
+
         if azure_storage_connection_string:
             self._creds = {
                 "azure_storage_connection_string": azure_storage_connection_string
             }
+        elif not self.unsigned:
+            self._creds = {
+                "azure_storage_account": self.storage_account,
+                "azure_storage_access_key": azure_storage_access_key
+            }
         else:
             self._creds = {
-                "azure_storage_account": azure_storage_account,
-                "azure_storage_access_key": azure_storage_access_key
+                "azure_storage_account": self.storage_account
             }
 
     @classmethod
@@ -583,8 +595,10 @@ class AzureSession(Session):
         bool
 
         """
-        return 'AZURE_STORAGE_CONNECTION_STRING' in config or (
-            'AZURE_STORAGE_ACCOUNT' in config and 'AZURE_STORAGE_ACCESS_KEY' in config
+        return (
+            'AZURE_STORAGE_CONNECTION_STRING' in config
+            or ('AZURE_STORAGE_ACCOUNT' in config and 'AZURE_STORAGE_ACCESS_KEY' in config)
+            or ('AZURE_STORAGE_ACCOUNT' in config and 'AZURE_NO_SIGN_REQUEST' in config)
         )
 
     @property
@@ -600,4 +614,10 @@ class AzureSession(Session):
         dict
 
         """
-        return {k.upper(): v for k, v in self.credentials.items()}
+        if self.unsigned:
+            return {
+                'AZURE_NO_SIGN_REQUEST': 'YES',
+                'AZURE_STORAGE_ACCOUNT': self.storage_account
+            }
+        else:
+            return {k.upper(): v for k, v in self.credentials.items()}
