@@ -18,6 +18,9 @@ SUPPORTED_RESAMPLING = [r for r in Resampling if r.value < 7]
 GDAL2_RESAMPLING = [r for r in Resampling if r.value > 7 and r.value <= 12]
 if GDALVersion.runtime().at_least('2.0'):
     SUPPORTED_RESAMPLING.extend(GDAL2_RESAMPLING)
+# sum supported since GDAL 3.1
+if GDALVersion.runtime().at_least('3.1'):
+    SUPPORTED_RESAMPLING.append(Resampling.sum)
 # rms supported since GDAL 3.3
 if GDALVersion.runtime().at_least('3.3'):
     SUPPORTED_RESAMPLING.append(Resampling.rms)
@@ -319,7 +322,7 @@ def reproject(source, destination=None, src_transform=None, gcps=None, rpcs=None
             else:
                 src_count = 1
                 src_height, src_width = source.shape
-            
+
             # try to compute src_bounds if we don't have gcps
             if not (gcps or rpcs):
                 src_bounds = array_bounds(src_height, src_width, src_transform)
@@ -331,9 +334,11 @@ def reproject(source, destination=None, src_transform=None, gcps=None, rpcs=None
             if not (src_rdr.transform.is_identity and src_rdr.crs is None):
                 src_bounds = src_rdr.bounds
 
-            src_crs = src_rdr.crs
+            src_crs = src_crs or src_rdr.crs
+
             if isinstance(src_bidx, int):
                 src_bidx = [src_bidx]
+
             src_count = len(src_bidx)
             src_height, src_width = src_shape
             gcps = src_rdr.gcps[0] if src_rdr.gcps[0] else None
@@ -475,10 +480,10 @@ def calculate_default_transform(
     """
     if any(x is not None for x in (left, bottom, right, top)) and gcps:
         raise ValueError("Bounding values and ground control points may not"
-                         "be used together.")
+                         " be used together.")
     if any(x is not None for x in (left, bottom, right, top)) and rpcs:
         raise ValueError("Bounding values and rational polynomial coefficients may not"
-                         "be used together.")
+                         " be used together.")
 
     if any(x is None for x in (left, bottom, right, top)) and not (gcps or rpcs):
         raise ValueError("Either four bounding values, ground control points,"
