@@ -1,13 +1,10 @@
 from pkg_resources import iter_entry_points
 
-from click.testing import CliRunner
-
 import rasterio
 from rasterio.rio.main import main_group
 
 
-def test_version():
-    runner = CliRunner()
+def test_version(runner):
     result = runner.invoke(main_group, ['--version'])
     assert result.exit_code == 0
     assert rasterio.__version__ in result.output
