@@ -1,12 +1,23 @@
+"""Test windows and indexing"""
+
+# TODO: break up multi-assertion tests.
+
 import numpy as np
 import pytest
 
 import rasterio
+from rasterio.errors import WindowError
 from rasterio import windows
 
+
 DATA_WINDOW = ((3, 5), (2, 6))
 
 
+def assert_window_almost_equals(a, b, precision=3):
+    for attr in ('row_off', 'col_off', 'width', 'height'):
+        assert round(getattr(a, attr), precision) == round(getattr(b, attr), precision)
+
+
 def test_index():
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         left, bottom, right, top = src.bounds
@@ -19,22 +30,25 @@ def test_index():
 def test_full_window():
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         left, bottom, right, top = src.bounds
-        assert src.window(left, bottom, right, top) == tuple(zip((0, 0), src.shape))
+        assert_window_almost_equals(
+            src.window(left, bottom, right, top),
+            windows.Window(0, 0, src.width, src.height))
 
 
 def test_window_no_exception():
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         left, bottom, right, top = src.bounds
         left -= 1000.0
-        assert src.window(left, bottom, right, top, boundless=True) == (
-                (0, src.height), (-4, src.width))
+        assert_window_almost_equals(
+            src.window(left, bottom, right, top),
+            windows.Window(-1000 / src.res[0], 0, src.width + 1000 / src.res[0], src.height))
 
 
 def test_index_values():
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         assert src.index(101985.0, 2826915.0) == (0, 0)
-        assert src.index(101985.0+400.0, 2826915.0) == (0, 1)
-        assert src.index(101985.0+400.0, 2826915.0-700.0) == (2, 1)
+        assert src.index(101985.0 + 400.0, 2826915.0) == (0, 1)
+        assert src.index(101985.0 + 400.0, 2826915.0 - 700.0) == (2, 1)
 
 
 def test_window():
@@ -42,28 +56,31 @@ def test_window():
         left, bottom, right, top = src.bounds
         dx, dy = src.res
         eps = 1.0e-8
-        assert src.window(
-            left+eps, bottom+eps, right-eps, top-eps) == ((0, src.height),
-                                                          (0, src.width))
-        assert src.index(left+400, top-400) == (1, 1)
-        assert src.index(left+dx+eps, top-dy-eps) == (1, 1)
-        assert src.window(left, top-400, left+400, top) == ((0, 2), (0, 2))
-        assert src.window(left, top-2*dy-eps, left+2*dx-eps, top) == ((0, 2), (0, 2))
+        assert_window_almost_equals(src.window(
+            left + eps, bottom + eps, right - eps, top - eps),
+            windows.Window(0, 0, src.width, src.height))
+        assert src.index(left + 400, top - 400) == (1, 1)
+        assert src.index(left + dx + eps, top - dy - eps) == (1, 1)
+        assert_window_almost_equals(src.window(left, top - 400, left + 400, top), windows.Window(0, 0, 400 / src.res[0], 400 / src.res[1]))
+        assert_window_almost_equals(src.window(left, top - 2 * dy - eps, left + 2 * dx - eps, top), windows.Window(0, 0, 2, 2))
 
 
 def test_window_bounds_roundtrip():
     with rasterio.open('tests/data/RGB.byte.tif') as src:
-        assert ((100, 200), (100, 200)) == src.window(
-            *src.window_bounds(((100, 200), (100, 200))))
+        assert_window_almost_equals(
+            windows.Window(100, 100, 100, 100),
+            src.window(*src.window_bounds(windows.Window(100, 100, 100, 100))))
 
 
 def test_window_full_cover():
 
-    def bound_covers(bounds1, bounds2):
+    def assert_bound_covers(bounds1, bounds2, precision=5):
         """Does bounds1 cover bounds2?
         """
-        return (bounds1[0] <= bounds2[0] and bounds1[1] <= bounds2[1] and
-                bounds1[2] >= bounds2[2] and bounds1[3] >= bounds2[3])
+        assert round(bounds1[0], precision) <= round(bounds2[0], precision)
+        assert round(bounds1[1], precision) <= round(bounds2[1], precision)
+        assert round(bounds1[2], precision) >= round(bounds2[2], precision)
+        assert round(bounds1[3], precision) >= round(bounds2[3], precision)
 
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         bounds = list(src.window_bounds(((100, 200), (100, 200))))
@@ -72,7 +89,7 @@ def test_window_full_cover():
 
         win = src.window(*bounds)
         bounds_calc = list(src.window_bounds(win))
-        assert bound_covers(bounds_calc, bounds)
+        assert_bound_covers(bounds_calc, bounds)
 
 
 @pytest.fixture
@@ -84,21 +101,21 @@ def data():
 
 def test_data_window_unmasked(data):
     window = windows.get_data_window(data)
-    assert window == ((0, data.shape[0]), (0, data.shape[1]))
+    assert window == windows.Window.from_slices((0, data.shape[0]), (0, data.shape[1]))
 
 
 def test_data_window_masked(data):
     data = np.ma.masked_array(data, data == 0)
     window = windows.get_data_window(data)
-    assert window == DATA_WINDOW
+    assert window == windows.Window.from_slices(*DATA_WINDOW)
 
 
 def test_data_window_nodata(data):
     window = windows.get_data_window(data, nodata=0)
-    assert window == DATA_WINDOW
+    assert window == windows.Window.from_slices(*DATA_WINDOW)
 
     window = windows.get_data_window(np.ones_like(data), nodata=0)
-    assert window == ((0, data.shape[0]), (0, data.shape[1]))
+    assert window == windows.Window.from_slices((0, data.shape[0]), (0, data.shape[1]))
 
 
 def test_data_window_nodata_disjunct():
@@ -107,46 +124,46 @@ def test_data_window_nodata_disjunct():
     data[1, 2:5, 2:8] = 1
     data[2, 1:6, 1:6] = 1
     window = windows.get_data_window(data, nodata=0)
-    assert window == ((0, 6), (1, 8))
+    assert window == windows.Window.from_slices((0, 6), (1, 8))
 
 
 def test_data_window_empty_result():
     data = np.zeros((3, 10, 10), dtype='uint8')
     window = windows.get_data_window(data, nodata=0)
-    assert window == ((0, 0), (0, 0))
+    assert window == windows.Window.from_slices((0, 0), (0, 0))
 
 
 def test_data_window_masked_file():
     with rasterio.open('tests/data/RGB.byte.tif') as src:
         window = windows.get_data_window(src.read(1, masked=True))
-        assert window == ((3, 714), (13, 770))
+        assert window == windows.Window.from_slices((3, 714), (13, 770))
 
         window = windows.get_data_window(src.read(masked=True))
-        assert window == ((3, 714), (13, 770))
+        assert window == windows.Window.from_slices((3, 714), (13, 770))
 
 
 def test_window_union():
     assert windows.union(
-        ((0, 6), (3, 6)),
-        ((2, 4), (1, 5))
-    ) == ((0, 6), (1, 6))
+        windows.Window(0, 3, 3, 6),
+        windows.Window(2, 1, 2, 4)
+    ) == windows.Window(0, 1, 4, 8)
 
 
 def test_window_intersection():
     assert windows.intersection(
         ((0, 6), (3, 6)),
         ((2, 4), (1, 5))
-    ) == ((2, 4), (3, 5))
+    ) == windows.Window.from_slices((2, 4), (3, 5))
 
     assert windows.intersection(
         ((0, 6), (3, 6)),
         ((2, 4), (1, 5)),
         ((3, 6), (0, 6))
-    ) == ((3, 4), (3, 5))
+    ) == windows.Window.from_slices((3, 4), (3, 5))
 
 
 def test_window_intersection_disjunct():
-    with pytest.raises(ValueError):
+    with pytest.raises(WindowError):
         windows.intersection(
             ((0, 6), (3, 6)),
             ((100, 200), (0, 12)),
@@ -191,7 +208,7 @@ def test_3x3matrix():
     arrangement = product(pairs, pairs)
     for wins in combinations(arrangement, 2):
         assert not windows.intersect(*wins)
-        with pytest.raises(ValueError):
+        with pytest.raises(WindowError):
             windows.intersection(*wins)
 
 
