@@ -2,6 +2,7 @@
 
 import json
 import logging
+import sys
 
 from affine import Affine
 import numpy as np
@@ -17,6 +18,7 @@ from rasterio.errors import (
     CRSError,
     GDALVersionError,
     TransformError,
+    WarpOperationError,
 )
 from rasterio.warp import (
     reproject,
@@ -1920,3 +1922,102 @@ def test_reproject_rpcs_approx_transformer(caplog):
         )
 
         assert "Created approximate transformer" in caplog.text
+
+
+@pytest.fixture
+def http_error_server(data):
+    """Serves files from the test data directory, poorly."""
+    import functools
+    import multiprocessing
+    import http.server
+    import os
+
+    from . import rangehttpserver
+
+    class RangeRequestErrorHandler(rangehttpserver.RangeRequestHandler):
+        """Return 500 for a range of bytes to simulate a malfunctioning server.
+
+        The byte range is specific to rasterio's RGB.byte.tif file.
+
+        """
+
+        def send_head(self):
+            if "Range" not in self.headers:
+                self.range = None
+                return super().send_head()
+            try:
+                self.range = rangehttpserver.parse_byte_range(self.headers["Range"])
+            except ValueError as e:
+                self.send_error(400, "Invalid byte range")
+                return None
+            first, last = self.range
+
+            # Our "poison byte" is at position 1609000.
+            if first <= 1609000 <= last:
+                self.send_error(500, "Boom!")
+                return None
+
+            # Mirroring SimpleHTTPServer.py here
+            path = self.translate_path(self.path)
+            f = None
+            ctype = self.guess_type(path)
+            try:
+                f = open(path, "rb")
+            except IOError:
+                self.send_error(404, "File not found")
+                return None
+
+            fs = os.fstat(f.fileno())
+            file_len = fs[6]
+            if first >= file_len:
+                self.send_error(416, "Requested Range Not Satisfiable")
+                return None
+
+            self.send_response(206)
+            self.send_header("Content-type", ctype)
+            self.send_header("Accept-Ranges", "bytes")
+
+            if last is None or last >= file_len:
+                last = file_len - 1
+            response_length = last - first + 1
+
+            self.send_header(
+                "Content-Range", "bytes %s-%s/%s" % (first, last, file_len)
+            )
+            self.send_header("Content-Length", str(response_length))
+            self.send_header("Last-Modified", self.date_time_string(fs.st_mtime))
+            self.end_headers()
+            return f
+
+    PORT = 8000
+    Handler = functools.partial(RangeRequestErrorHandler, directory=str(data))
+    httpd = http.server.HTTPServer(("", PORT), Handler)
+    p = multiprocessing.Process(target=httpd.serve_forever)
+    p.start()
+    yield
+    p.terminate()
+    p.join()
+
+
+@requires_gdal3
+@pytest.mark.skipif(
+    sys.version_info < (3, 7),
+    reason="Python 3.7 required to serve the data fixture directory",
+)
+def test_reproject_error_propagation(http_error_server, caplog):
+    """Propagate errors up from ChunkAndWarpMulti and check for a retry."""
+
+    with rasterio.open(
+        "/vsicurl?max_retry=1&retry_delay=.1&url=http://localhost:8000/RGB.byte.tif"
+    ) as src:
+        out = np.zeros((src.count, src.height, src.width), dtype="uint8")
+
+        with pytest.raises(WarpOperationError):
+            reproject(
+                rasterio.band(src, (1, 2, 3)),
+                out,
+                dst_crs=src.crs,
+                dst_transform=src.transform,
+            )
+
+    assert len([rec for rec in caplog.records if "Retrying again" in rec.message]) == 2
