@@ -107,8 +107,12 @@ def test_write_sbyte(tmpdir):
     with rasterio.open(
             name, 'w',
             driver='GTiff', width=100, height=100, count=1,
-            dtype=a.dtype) as s:
-        s.write(a, indexes=1)
+            dtype=a.dtype) as dst:
+        dst.write(a, indexes=1)
+
+    with rasterio.open(name) as dst:
+        assert (dst.read() == -33).all()
+
     info = subprocess.check_output(["gdalinfo", "-stats", name]).decode('utf-8')
     assert "Minimum=-33.000, Maximum=-33.000, Mean=-33.000, StdDev=0.000" in info
     assert 'SIGNEDBYTE' in info
@@ -176,12 +180,22 @@ def test_write_crs_transform(tmpdir):
                               0.0, -300.041782729805, 2826915.0)
 
     with rasterio.open(
-            name, 'w',
-            driver='GTiff', width=100, height=100, count=1,
-            crs={'units': 'm', 'no_defs': True, 'ellps': 'WGS84',
-                 'proj': 'utm', 'zone': 18},
-            transform=transform,
-            dtype=rasterio.ubyte) as s:
+        name,
+        "w",
+        driver="GTiff",
+        width=100,
+        height=100,
+        count=1,
+        crs={
+            "units": "m",
+            "no_defs": True,
+            "datum": "WGS84",
+            "proj": "utm",
+            "zone": 18,
+        },
+        transform=transform,
+        dtype=rasterio.ubyte,
+    ) as s:
         s.write(a, indexes=1)
     assert s.crs.to_epsg() == 32618
     info = subprocess.check_output(["gdalinfo", name]).decode('utf-8')
@@ -197,12 +211,22 @@ def test_write_crs_transform_affine(tmpdir):
     transform = affine.Affine(300.0379266750948, 0.0, 101985.0,
                               0.0, -300.041782729805, 2826915.0)
     with rasterio.open(
-            name, 'w',
-            driver='GTiff', width=100, height=100, count=1,
-            crs={'units': 'm', 'no_defs': True, 'ellps': 'WGS84',
-                 'proj': 'utm', 'zone': 18},
-            transform=transform,
-            dtype=rasterio.ubyte) as s:
+        name,
+        "w",
+        driver="GTiff",
+        width=100,
+        height=100,
+        count=1,
+        crs={
+            "units": "m",
+            "no_defs": True,
+            "datum": "WGS84",
+            "proj": "utm",
+            "zone": 18,
+        },
+        transform=transform,
+        dtype=rasterio.ubyte,
+    ) as s:
         s.write(a, indexes=1)
 
     assert s.crs.to_epsg() == 32618
@@ -243,7 +267,8 @@ def test_write_crs_transform_3(tmpdir):
     a = np.ones((100, 100), dtype=rasterio.ubyte) * 127
     transform = affine.Affine(300.0379266750948, 0.0, 101985.0,
                               0.0, -300.041782729805, 2826915.0)
-    wkt = 'PROJCS["UTM Zone 18, Northern Hemisphere",GEOGCS["WGS 84",DATUM["unknown",SPHEROID["WGS84",6378137,298.257223563]],PRIMEM["Greenwich",0],UNIT["degree",0.0174532925199433]],PROJECTION["Transverse_Mercator"],PARAMETER["latitude_of_origin",0],PARAMETER["central_meridian",-75],PARAMETER["scale_factor",0.9996],PARAMETER["false_easting",500000],PARAMETER["false_northing",0],UNIT["Meter",1]]'
+    wkt = 'PROJCS["WGS 84 / UTM zone 18N",GEOGCS["WGS 84",DATUM["WGS_1984",SPHEROID["WGS 84",6378137,298.257223563,AUTHORITY["EPSG","7030"]],AUTHORITY["EPSG","6326"]],PRIMEM["Greenwich",0,AUTHORITY["EPSG","8901"]],UNIT["degree",0.0174532925199433,AUTHORITY["EPSG","9122"]],AUTHORITY["EPSG","4326"]],PROJECTION["Transverse_Mercator"],PARAMETER["latitude_of_origin",0],PARAMETER["central_meridian",-75],PARAMETER["scale_factor",0.9996],PARAMETER["false_easting",500000],PARAMETER["false_northing",0],UNIT["metre",1,AUTHORITY["EPSG","9001"]],AXIS["Easting",EAST],AXIS["Northing",NORTH],AUTHORITY["EPSG","32618"]]'
+
     with rasterio.open(
             name, 'w',
             driver='GTiff', width=100, height=100, count=1,
@@ -253,7 +278,7 @@ def test_write_crs_transform_3(tmpdir):
         s.write(a, indexes=1)
     assert s.crs.to_epsg() == 32618
     info = subprocess.check_output(["gdalinfo", name]).decode('utf-8')
-    assert '"UTM Zone 18, Northern Hemisphere",' in info
+    assert 'UTM zone 18N' in info
     # make sure that pixel size is nearly the same as transform
     # (precision varies slightly by platform)
     assert re.search(r'Pixel Size = \(300.03792\d+,-300.04178\d+\)', info)
